@@ -14,6 +14,7 @@ use std::sync::Arc;
 
 /// Configuration for QuicBackendAdapt
 #[non_exhaustive]
+#[derive(Default)]
 pub struct QuicConfig {
     /// Tls config
     /// Default: None = ephemeral.
@@ -24,15 +25,6 @@ pub struct QuicConfig {
     pub tuning_params: Option<KitsuneP2pTuningParams>,
 }
 
-impl Default for QuicConfig {
-    fn default() -> Self {
-        Self {
-            tls: None,
-            tuning_params: None,
-        }
-    }
-}
-
 impl QuicConfig {
     /// into inner contents with default application
     pub async fn split(self) -> KitsuneResult<(TlsConfig, KitsuneP2pTuningParams)> {
@@ -43,7 +35,7 @@ impl QuicConfig {
             Some(tls) => tls,
         };
 
-        let tuning_params = tuning_params.unwrap_or_else(KitsuneP2pTuningParams::default);
+        let tuning_params = tuning_params.unwrap_or_default();
 
         Ok((tls, tuning_params))
     }
@@ -313,9 +305,9 @@ impl EndpointAdapt for QuicEndpointAdapt {
         use kitsune_p2p_types::dependencies::url2;
         let mut url = url2::url2!("{}://{}", crate::SCHEME, addr);
 
-        // TODO - FIXME - not sure how slow `get_if_addrs` is
-        //                might be better to do this once on bind
-        //                and just cache the bound address
+        // MAYBE - not sure how slow `get_if_addrs` is
+        //         might be better to do this once on bind
+        //         and just cache the bound address
         if let Some(host) = url.host_str() {
             if host == "0.0.0.0" {
                 for iface in if_addrs::get_if_addrs().map_err(KitsuneError::other)? {
